==> cryptol-2.6.0-79-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.6.0
id: cryptol-2.6.0-L9Og2WnjeIQBcPYwAwS1yk
key: cryptol-2.6.0-L9Og2WnjeIQBcPYwAwS1yk
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: ba092fa2119ad76f1576c28067c171af
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Fixity Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Unlit Cryptol.Parser.Utils Cryptol.Prims.Eval
    Cryptol.Prims.Syntax Cryptol.REPL.Command Cryptol.REPL.Monad
    Cryptol.REPL.Trie Cryptol.Symbolic Cryptol.Symbolic.Prims
    Cryptol.Symbolic.Value Cryptol.Testing.Concrete
    Cryptol.Testing.Random Cryptol.Transform.AddModParams
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST
    Cryptol.TypeCheck.CheckModuleInstance Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Depends Cryptol.TypeCheck.Error
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.6.3/site-local/cryptol-2.6.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/cryptol-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.6.0-L9Og2WnjeIQBcPYwAwS1yk
depends:
    GraphSCC-1.0.4-3OePO7VIpTKFKEtcZOuY34 array-0.5.3.0 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    monad-control-1.0.2.3-C7Mt0wi6Itk30zmrdYvypZ
    monadLib-3.9-Ck8eU2kCDDMFvpmDhfp0fP mtl-2.2.2
    panic-0.4.0.1-D8Exh3GzUgS4bY0vj8bs9f pretty-1.1.3.6 process-1.6.3.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q sbv-7.13-2XpRoIFInUHIbMTbR2VD1x
    simple-smt-0.9.3-12ogCUTCLIkI8uI0lTrqx6
    strict-0.3.2-2aeC0uPBzhhHpNCyMYHGTD text-1.2.3.1
    tf-random-0.5-DGXDH2T2OVbHHRLZ895CUL time-1.8.0.2
    transformers-base-0.4.5.2-CYvZwiYe2CEFBvY3nUdZ2C
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cryptol-2.6.0-84-x86_64.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.6.0
id: cryptol-2.6.0-9dGUxSA18wH84xAT7be2tI
key: cryptol-2.6.0-9dGUxSA18wH84xAT7be2tI
license: BSD-3-Clause
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
author: Galois, Inc.
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
abi: 8acb3744b95f2dc2f9ffe5488c7ded03
exposed: True
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.IR.FreeVars Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Exports
    Cryptol.ModuleSystem.InstantiateModule
    Cryptol.ModuleSystem.Interface Cryptol.ModuleSystem.Monad
    Cryptol.ModuleSystem.Name Cryptol.ModuleSystem.NamingEnv
    Cryptol.ModuleSystem.Renamer Cryptol.Parser Cryptol.Parser.AST
    Cryptol.Parser.Fixity Cryptol.Parser.Lexer Cryptol.Parser.Name
    Cryptol.Parser.Names Cryptol.Parser.NoInclude Cryptol.Parser.NoPat
    Cryptol.Parser.Position Cryptol.Parser.Selector
    Cryptol.Parser.Unlit Cryptol.Parser.Utils Cryptol.Prims.Eval
    Cryptol.Prims.Syntax Cryptol.REPL.Command Cryptol.REPL.Monad
    Cryptol.REPL.Trie Cryptol.Symbolic Cryptol.Symbolic.Prims
    Cryptol.Symbolic.Value Cryptol.Testing.Concrete
    Cryptol.Testing.Random Cryptol.Transform.AddModParams
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST
    Cryptol.TypeCheck.CheckModuleInstance Cryptol.TypeCheck.Default
    Cryptol.TypeCheck.Depends Cryptol.TypeCheck.Error
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Parseable Cryptol.TypeCheck.Sanity
    Cryptol.TypeCheck.SimpType Cryptol.TypeCheck.SimpleSolver
    Cryptol.TypeCheck.Solve Cryptol.TypeCheck.Solver.Class
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Logger
    Cryptol.Utils.Misc Cryptol.Utils.PP Cryptol.Utils.Panic
    Cryptol.Utils.Patterns Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
import-dirs: /usr/lib/ghc-8.6.3/site-local/cryptol-2.6.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/cryptol-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.6.0-9dGUxSA18wH84xAT7be2tI
depends:
    GraphSCC-1.0.4-3OePO7VIpTKFKEtcZOuY34 array-0.5.3.0 base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 deepseq-1.4.4.0 directory-1.3.3.0
    filepath-1.4.2.1 gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
    heredoc-0.2.0.0-5CGfN4QKKxO6xWz8UL0AnE
    monad-control-1.0.2.3-8mWjhu0S94p37ozPEL8Dki
    monadLib-3.9-Ck8eU2kCDDMFvpmDhfp0fP mtl-2.2.2
    panic-0.4.0.1-D8Exh3GzUgS4bY0vj8bs9f pretty-1.1.3.6 process-1.6.3.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q sbv-7.13-Iq9MlXm39zn83CDMD7B629
    simple-smt-0.9.4-EY8axe5bLsgBJeOsoY3lta
    strict-0.3.2-2aeC0uPBzhhHpNCyMYHGTD text-1.2.3.1
    tf-random-0.5-DGXDH2T2OVbHHRLZ895CUL time-1.8.0.2
    transformers-base-0.4.5.2-6sqJnZSEiKyFksWegWCsAG
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
